.. include:: ../BADGES.rst

astronomia Package
==================

:mod:`calendar` Module
----------------------

.. automodule:: astronomia.calendar
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`coordinates` Module
-------------------------

.. automodule:: astronomia.coordinates
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dynamical` Module
-----------------------

.. automodule:: astronomia.dynamical
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`lunar` Module
---------------------

.. automodule:: astronomia.lunar
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`equinox` Module
---------------------

.. automodule:: astronomia.equinox
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nutation` Module
----------------------

.. automodule:: astronomia.nutation
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`riseset` Module
---------------------

.. automodule:: astronomia.riseset
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sun` Module
-----------------

.. automodule:: astronomia.sun
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`util` Module
------------------

.. automodule:: astronomia.util
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`planets` Module
---------------------

.. automodule:: astronomia.planets
    :members:
    :undoc-members:
    :show-inheritance:
